import { EventCondition } from "./condition";
import { MilestoneKey } from "./keys";

export type MilestoneInformation = {
  title: string;
  description: string;
  condition: EventCondition;
};

export const milestoneInformation: {
  [key in MilestoneKey]: MilestoneInformation;
} = {
  start: {
    title: "Ready to start",
    description:
      "You have everything you need to start on your journey to creating a drone. All you need is the will to do so.",
    condition: { hasResources: { rawChemicals: { minQuantity: 1 } } },
  },
  "subject-1": {
    title: "First subject",
    description: "Invite somebody to participate in your drone experiment.",
    condition: { hasWorld: { capturedPopulation: { minQuantity: 1 } } },
  },
  "drone-1": {
    title: "It Begins",
    description: "Obtain your first drone",
    condition: { hasWorld: { dronePopulation: { minQuantity: 1 } } },
  },
  "drone-2": {
    title: "Technically Not A Threesome",
    description: "Obtain your second drone",
    condition: { hasWorld: { dronePopulation: { minQuantity: 2 } } },
  },
  "drone-5": {
    title: "Polycule",
    description: "Obtain your fifth drone",
    condition: { hasWorld: { dronePopulation: { minQuantity: 5 } } },
  },
  "drone-10": {
    title: "Not a startup anymore",
    description: "Obtain your tenth drone",
    condition: { hasWorld: { dronePopulation: { minQuantity: 10 } } },
  },
  "drone-20": {
    title: "Twenty's company",
    description: "Obtain your twentieth drone",
    condition: { hasWorld: { dronePopulation: { minQuantity: 20 } } },
  },
  "drone-50": {
    title: "Fifty",
    description: "Obtain your fiftieth drone",
    condition: { hasWorld: { dronePopulation: { minQuantity: 50 } } },
  },
  "drone-100": {
    title: "Hundred",
    description: "Obtain your hundreth drone",
    condition: { hasWorld: { dronePopulation: { minQuantity: 100 } } },
  },
  "drone-250": {
    title: "Quarter of a Thousand",
    description: "Obtain your two hundred and fiftieth drone",
    condition: { hasWorld: { dronePopulation: { minQuantity: 250 } } },
  },
  "drone-500": {
    title: "Small Town",
    description: "Obtain your five hundredth drone",
    condition: { hasWorld: { dronePopulation: { minQuantity: 500 } } },
  },
  "drone-1000": {
    title: "Mall-sized",
    description: "Obtain your thousandth drone",
    condition: { hasWorld: { dronePopulation: { minQuantity: 1000 } } },
  },
  "drone-5000": {
    title: "First Drone",
    description: "Obtain your five thousandth drone",
    condition: { hasWorld: { dronePopulation: { minQuantity: 5000 } } },
  },
  "drone-10000": {
    title: "The first was so far away...",
    description: "Obtain your ten thousandth drone",
    condition: { hasWorld: { dronePopulation: { minQuantity: 10000 } } },
  },
  "drone-50000": {
    title: "City-Sized",
    description: "Obtain your fifty thousandth drone",
    condition: { hasWorld: { dronePopulation: { minQuantity: 50000 } } },
  },
  "drone-100000": {
    title: "County",
    description: "Obtain your hundred thousandth drone",
    condition: { hasWorld: { dronePopulation: { minQuantity: 100000 } } },
  },
  "drone-500000": {
    title: "State",
    description: "Obtain your five hundred thousandth drone",
    condition: { hasWorld: { dronePopulation: { minQuantity: 500000 } } },
  },
  "drone-1000000": {
    title: "Golden",
    description: "Obtain your millionth drone",
    condition: { hasWorld: { dronePopulation: { minQuantity: 1000000 } } },
  },
  "drone-5000000": {
    title: "Country",
    description: "Obtain your five millionth drone",
    condition: { hasWorld: { dronePopulation: { minQuantity: 5000000 } } },
  },
  "drone-10000000": {
    title: "Independence",
    description: "Obtain your ten millionth drone",
    condition: { hasWorld: { dronePopulation: { minQuantity: 10000000 } } },
  },
  "drone-100000000": {
    title: "Continent",
    description: "Obtain your hundred millionth drone",
    condition: { hasWorld: { dronePopulation: { minQuantity: 100000000 } } },
  },
  "drone-1000000000": {
    title: "Nearly there",
    description: "Obtain your billionth drone",
    condition: { hasWorld: { dronePopulation: { minQuantity: 1000000000 } } },
  },
  "drone-all": {
    title: "Worldwide hive",
    description: "Turn the whole planet into drones",
    condition: { hasWorld: { freePopulation: { maxQuantity: 1 } } },
  },
  "drone-retriever-1": {
    title: "Kidnapper",
    description: "Obtain your first retriever drone",
    condition: { hasResources: { retrieverDrone: { minQuantity: 1 } } },
  },
  "drone-retriever-10": {
    title: "Taskforce",
    description: "Obtain your tenth retriever drone",
    condition: { hasResources: { retrieverDrone: { minQuantity: 10 } } },
  },
  "drone-retriever-100": {
    title: "Mafia",
    description: "Obtain your hundredth retriever drone",
    condition: { hasResources: { retrieverDrone: { minQuantity: 100 } } },
  },
  "drone-retriever-1000": {
    title: "Militia",
    description: "Obtain your thousandth retriever drone",
    condition: { hasResources: { retrieverDrone: { minQuantity: 1000 } } },
  },
  "drone-retriever-10000": {
    title: "Army",
    description: "Obtain your ten thousandth retriever drone",
    condition: { hasResources: { retrieverDrone: { minQuantity: 10000 } } },
  },
  "drone-converter-1": {
    title: "Automated",
    description: "Obtain your first converter drone",
    condition: { hasResources: { converterDrones: { minQuantity: 1 } } },
  },
  "drone-converter-10": {
    title: "Imprinting Process",
    description: "Obtain your tenth converter drone",
    condition: { hasResources: { converterDrones: { minQuantity: 10 } } },
  },
  "drone-converter-100": {
    title: "Runaway",
    description: "Obtain your hundredth converter drone",
    condition: { hasResources: { converterDrones: { minQuantity: 100 } } },
  },
  "drone-researcher-1": {
    title: "Outsourced",
    description: "Obtain your first researcher drone",
    condition: { hasResources: { researcherDrones: { minQuantity: 1 } } },
  },
  "drone-researcher-10": {
    title: "Laboratory",
    description: "Obtain your tenth researcher drone",
    condition: { hasResources: { researcherDrones: { minQuantity: 10 } } },
  },
  "drone-researcher-100": {
    title: "Unthink Tank",
    description: "Obtain your hundredth researcher drone",
    condition: { hasResources: { researcherDrones: { minQuantity: 100 } } },
  },
  "drone-overseer-1": {
    title: "Middle Management",
    description: "Obtain your first overseer drone",
    condition: { hasResources: { overseerDrones: { minQuantity: 1 } } },
  },
  "drone-overseer-10": {
    title: "Director Board",
    description: "Obtain your tenth overseer drone",
    condition: { hasResources: { overseerDrones: { minQuantity: 10 } } },
  },
  "drone-overseer-100": {
    title: "Decentralized Authority",
    description: "Obtain your hundredth overseer drone",
    condition: { hasResources: { overseerDrones: { minQuantity: 100 } } },
  },
};
