import {
  ResourcesKeys,
  ResearchKeys,
  WorldKeys,
  StoryKeys,
  MilestoneKey,
} from "./keys";

export type ResourceStoreData = {
  quantity: number;
  totalDuration?: number;
  remainingDuration?: number;
  isPaused?: boolean;
};

export type StoreResources = {
  [key in ResourcesKeys]?: ResourceStoreData;
};

export type StoreResearchEntry = {
  level: number;
};

export type StoreResearch = {
  [key in ResearchKeys]?: StoreResearchEntry;
};

export type StoreTaskAcquireGoal = {
  type: "acquire";
  resource: ResourcesKeys;
};

export type StoreTaskResearchGoal = {
  type: "research";
  research: ResearchKeys;
};

export type StoreTask = {
  name: string;
  description: string;
  totalDuration: number;
  remainingDuration: number;
  goal: StoreTaskAcquireGoal | StoreTaskResearchGoal;
};

export type PastStoryEntry = {
  id: StoryKeys;
  date: string;
  text: Array<string | { type: "image"; url: string }>;
};

export type WorldStore = {
  [key in WorldKeys]: number;
};

export type Store = {
  resources: StoreResources;
  research: StoreResearch;
  story: PastStoryEntry[];
  storyEvents: StoryKeys[];
  tasks: StoreTask[];
  milestones: MilestoneKey[];
  world: WorldStore;
  startDate: number;
  timeElapsedMilliseconds: number;
  screenIsClickable: boolean;
};

export type ResourcesRequirement = { [key in keyof StoreResources]?: number };

export function createDefaultStore(): Store {
  return {
    resources: {},
    research: {},
    story: [],
    storyEvents: [],
    tasks: [],
    milestones: [],
    world: {
      freePopulation: 8000000000 + Math.ceil(Math.random() * 1000000000),
      capturedPopulation: 0,
      capturedUnprocessedPopulation: 0,
      dronePopulation: 0,
      maxRawChemicalsStored: 0,
      maxBrainwashingMaterialsStored: 0,
    },
    startDate:
      Math.ceil((1830297600 + Math.random() * 31536000) / 60 / 60) *
      60 *
      60 *
      1000,
    timeElapsedMilliseconds: 0,
    screenIsClickable: true,
  };
}
