import { EventCondition } from "./condition";
import { StoryKeys } from "./keys";
import { Store } from "./store";

export type StoryEventInformation = {
  id: StoryKeys;
  text: Array<string | { type: "image"; url: string }>;
  condition: EventCondition;
  onConfirmScene: (store: Store) => Store;
};

export const storySteps: StoryEventInformation[] = [
  {
    id: "unlock-raw-chemicals",
    text: [
      "The defense contract paid very, very well, and the bonus to ensure your secrecy was nice as well. You're not even in your forties, and you're already retired. You've about enough money to do whatever you want.",
      "You just acquired a farm at the edge of the town of Iron Falls, Nevada. It's a large, comfortable place, perfect for inviting friends over.",
      "Still, 'retired' or not you're a scientist. And you're not planning to stop doing more science.",
      "You idly sift through some of your notes, the ones you didn't destroy or leave behind at the office. You tell yourself it's to know what to do next.",
      "But, whatever yo do, you keep going back to that one formula, scribbled in a margin.",
      "Back then, while working for the government, you were tasked with creating a formula for a brainwashing agent. It was after you made immense progress on other tasks, and gained a lot of trust from the directors, a bit before you left. You were given a large amount of resources for it. Even human subjects to run experiments on if you needed to.",
      "Of course, the formula you scribbled never actually worked. You made sure your report mentioned the very bad side-effects of the individual chemicals you tested, and the deadly result when combining them all. You made your provider replace your entire labware after this test, to ensure there was no cross-contamination that could accidentally harm other people.",
      "You also remember the day you tested it, the blank face of the subject as you made their mind soft and malleable. The way they followed simple suggestions with a peaceful smile on their face. The days of monitoring after the process, when they told you all about how it felt to be under. The way they were rewritten to forget about the experiment, about the results, and even about the fact they ever entered your lab.",
      "With that done, nobody knows you fudged the results of that report. For good reason, of course. This is power that nobody should be trusted with, not even the government.",
      "Still, you don't know why you held onto this formula. You left that life behind with the rest of the contract. This is one of the reasons why you chose to retire, after all.",
      "But still, you can't help but thinking back to it...",
      "You wouldn't do it for real. But you're also kind of wondering. You could synthetize more of it, and try it on someone. Just to see how far they'll go, how much they'll obey, just to see if you really can turn a human into a blissful, mindless drone.",
      "All you'd have to do is to open your browser and order some chemicals...",
      "<New resource available: Raw Chemicals>",
    ],
    condition: {},
    onConfirmScene: (store) => {
      store.resources.rawChemicals = { quantity: 0 };
      return store;
    },
  },
  {
    id: "unlock-brainwashing-materials",
    text: [
      "That's it. The package just arrived, with a few warnings on it that you recognize from work. With your contacts, it wasn't that difficult to acquire them, but it's not something everyone would be able to get either.",
      "Now, these are just some raw materials. You can't really do anything with it as-is, except maybe give yourself a headache if you inhale them.",
      "But, if you just combine them in a specific way, you know what would happen...",
      "<New resource available: Brainwashing Material>",
    ],
    condition: { hasResources: { rawChemicals: { minQuantity: 1 } } },
    onConfirmScene: (store) => {
      store.resources.brainwashingMaterials = { quantity: 0 };
      return store;
    },
  },
  {
    id: "unlock-unprocessed-subject",
    text: [
      "You gaze at your creation. The swirling liquid inside of your flask is enough to rewire somebody's neurons once injected. You've seen it work already, you're confident it will work again.",
      "You even managed to create two doses instead of one like you expected. Beginner's luck, you don't expect that to happen ever again.",
      "<Extra resource acquired: Brainwashing Materials x1>",
      "You safely store both of the IV bags in your fridge. Of course, now, the question is whether you'll actually test it or someone, or not.",
      "You really don't feel like kidnapping a random person to try it on, no, that's not the kind of person you are.",
      "But if somebody were to volunteer? If they knew the risks when going into it? Well, you think... Maybe you'd be comfortable with it then.",
      "You're already familiar about some corners of the internet. You're in a few chatrooms already. You know there's people there who'd volunteer if you asked.",
      "Should you ask, though? Is it what you want to do? You can't help but ponder the question.",
      "<New resource available: Unprocessed Subject>",
    ],
    condition: { hasResources: { brainwashingMaterials: { minQuantity: 1 } } },
    onConfirmScene: (store) => {
      if (store.resources.brainwashingMaterials)
        store.resources.brainwashingMaterials.quantity += 1;
      store.resources.unprocessedSubjects = { quantity: 0 };
      return store;
    },
  },
  {
    id: "unlock-blank-drone",
    text: [
      "Honestly, you don't regret the past few hours. It was fun catching up with everyone, you really didn't have that much time to hang out for the past few months.",
      "You also reconnected with Lily. She's somebody you've talked with for years, one of the first ones you met in these circles. She's already into dronification, that's even how you met.",
      "You already trust her, too. You told her your secret, what you did the past few months, what you just did earlier. You told her about the doses of chemical you have already, the ones ready to be used.",
      "She almost didn't believe you, but she also knows you. She's interested, to say the least.",
      "So, you invited her to your home. Talked about it some more. Showed her the formula, the test results, your fridge's contents.",
      "The way her eyes lit up as you showed it to her lifted a lot of your doubts.",
      "She gave you full consent to start the process. It's an opportunity like no other. You just need to use the dose.",
      "<New drone available: Blank Drone>",
    ],
    condition: { hasResources: { unprocessedSubjects: { minQuantity: 1 } } },
    onConfirmScene: (store) => {
      store.resources.blankDrones = { quantity: 0 };
      return store;
    },
  },
  {
    id: "unlock-crafter-drone",
    text: [
      "You watch Lily's face as the chemicals start acting. The way her traits soften, the way her eyelids flutter. You take a couple minutes just watching it act, how her face changes as relaxation takes over, how her body slouches comfortably in your living room's couch.",
      "After waiting a bit longer, you take the second component - a virtual reality helmet, repurposed specially for this. You slip it over her eyes, and she sighs dreamily as flashing lights start remolding her brain.",
      "You don't have to do much, honestly. The process mostly runs itself.",
      "After a few hours, Lily - no, not Lily, Drone #0001 - open its eyes. It stares forwards blankly.",
      "You let it rest for a few moments, but you'll have to give it something to do.",
      "You think you'll start by teaching it how to combine more of the chemicals together, for now.",
      "<New drone available: Crafter Drone>",
    ],
    condition: { hasResources: { blankDrones: { minQuantity: 1 } } },
    onConfirmScene: (store) => {
      store.resources.crafterDrones = { quantity: 0 };
      return store;
    },
  },
  {
    id: "unlock-second-subject",
    text: [
      "It takes a while. You have to walk your drone through mixing the chemicals, creating the formula, and constantly check whether the proportions are right.",
      "Your drone is competent, at least. It follows orders exactly to the letter. You're just finding that creating the chemical yourself relied a lot more on your own intuition than on any precise doses or mixing - so far, at least.",
      "Still, it's an opportunity to write it all down. And it only takes you a few hours of extra training.",
      "You watch expectantly as Drone #0001 executes the steps, its movements precisely what you taught it. It manages to create an extra dose of brainwashing material, which you store away as well.",
      "Drone #0001 is now ready for service as a crafter.",
      "It's not all you need Drone #0001 for, though. Now that you have an example - a living, breathing example - of what your drug can do, you're kind of hoping it could convince more people to join.",
      "You ask Drone #0001 to send a message to one of Lily's kinky friend, Joan. As you recall from Lily's descriptions, Joan would be interested in joining a hive-mind as well, but unlike Lily you don't know her that well.",
      "Maybe, if you try to convince her enough, you can recruit her.",
      "<New objective: Obtain a second subject>",
    ],
    condition: { hasResources: { crafterDrones: { minQuantity: 1 } } },
    onConfirmScene: (store) => {
      if (store.resources.brainwashingMaterials)
        store.resources.brainwashingMaterials.quantity += 1;
      return store;
    },
  },
  {
    id: "unlock-second-drone",
    text: [
      "It's... Surprisingly easy, after all. Joan isn't convinced right away, but after sending a few pictures of Drone #0001 in its latex outfit, she's quick to turn around.",
      "Well. She tells you that it still looks like kinky roleplay to her, but she's okay with it if it actually is more. Anyways. You don't need your subjects to believe in brainwashing, it works just as well without that.",
      "After the promise that Drone #0001 will be there the whole time, she accepts to come to your place and participate in the process.",
      "She doesn't live too far away, so it only takes her one hour or so to get here. You talk a little bit, but you both can't wait to go forward with it.",
      "<New objective: Convert your second subject into a drone>",
    ],
    condition: {
      hasResources: {
        crafterDrones: { minQuantity: 1 },
        unprocessedSubjects: { minQuantity: 1 },
      },
    },
    onConfirmScene: (store) => {
      return store;
    },
  },
  {
    id: "unlock-gatherer-drone",
    text: [
      "Jane goes under quickly after you start the I.V., just like Lily did. Maybe even faster. You're watching her as she does, telling yourself that you're monitoring it, but you somehow forget to take notes. No matter, that's what the camera recording is for.",
      "After a while, you strap the helmet on her. It's nice, and looks pretty. You feel nice, seeing her go under even more.",
      "The process itself isn't especially fast. You alternate between watching Drone #0001 work, and monitoring Jane's vitals.",
      "Then, finally, after a few hours, Jane pushes back the helmet. She stares at you, but on the other side, you don't see a human anymore. You see Drone #0002, ready for further programming.",
      "Now, you have the option of turning your second drone into a Crafter as well, to get twice the output when crafting. Or you could train it to order components for you instead. Your choice.",
      "<New drone available: Gatherer Drone>",
      "In addition to getting a second drone, you're also already considering your next options. You know Lily and Joan had a few other friends who would be happy to join in, especially now that they can both participate. And you know there's people outside of that circle of friends too, that you could contact, and that could be interested as well.",
      "This is starting to go way further than an experiment, however. But, does it matter? Do you really feel like stopping at an experiment?",
      "You certainly have the option of going further...",
      "<New objective: Obtain five drones>",
    ],
    condition: { hasWorld: { dronePopulation: { minQuantity: 2 } } },
    onConfirmScene: (store) => {
      store.resources.gathererDrones = { quantity: 0 };
      return store;
    },
  },
  {
    id: "unlock-brainwashing-chamber",
    text: [
      "You were quite busy these past few days.",
      "First, there's recruitment. You now have five drones, the latest of which is sitting in a comfortable chair, its face peacefully blank and ready to be imprinted into anything.",
      "Then, there's documentation. Because, yes, you started taking more notes about the brainwashing process, the way to inject the product into people, and the time it takes for the product to take effect with an optimal dose.",
      "You're getting confident that you can automate that part of the process. And you don't mean, like, make a drone do it for you. There's just too much waiting around for that to be worth doing.",
      "No, you mean, encoding the process into a machine. It would take a lot of resources to actually make it happen, but... Yeah. That seems like something worth doing, especially if you plan on getting more people.",
      "Even if it's slower than doing it yourself, it's time you can spend doing other things. Totally worth it.",
      "<New building available: Brainwashing Chamber>",
      "<New objective: Obtain ten drones>",
    ],
    condition: { hasWorld: { dronePopulation: { minQuantity: 5 } } },
    onConfirmScene: (store) => {
      store.resources.brainwashingChambers = { quantity: 0 };
      return store;
    },
  },
  {
    id: "unlock-service-drone",
    text: [
      "Ten drones.",
      "As you look around the room, at the busy activity as some of them craft things or order things, you can't help but appreciate the result. You certainly like the aesthetic of being surrounded by dreamlike, latex-clad beings.",
      "What you appreciate a bit less, however, is the maintenance they all take. Sure, they're mostly autonomous, but you kind of need to be there to take care of them nonetheless - they need guidance, maintenance, regulated sleep and prepared meals.",
      "The solution is obvious, of course. Take one more drone and teach it how to do all that for you.",
      "Of course, you already have ten drones total, which is your limit, but drones should also be better than you at servicing other drones. You're not sure how many drones they can handle, but probably enough.",
      "Doing that should give you more time to focus on what you like again, like research, for example.",
      "So, just a little bit more work and you're free to focus again.",
      "<New drone available: Service Drone>",
      "<New objective: Obtain 25 drones>",
    ],
    condition: { hasWorld: { dronePopulation: { minQuantity: 10 } } },
    onConfirmScene: (store) => {
      store.resources.serviceDrone = { quantity: 0 };
      return store;
    },
  },
  {
    id: "unlock-retriever-drone",
    text: [
      "You now have twenty-five drones roaming around in your building. Twenty-five happy, blank, sexy human shells for the perfected automatons running inside of them.",
      "Up until this morning, you'd say that this is one of the highest points in your life.",
      "Then, you saw the flash, right before the shadow passed near your window. You went outside just fast enough to catch the rear of a car.",
      "Thankfully, you have contacts. This is a simple matter, a local journalist. You can guess that she was snooping around your home, and saw something happening.",
      "Now, you're really happy here, but the townspeople would probably be less than happy if they get wind of that information.",
      "You have some time. She's not going to publish that article too soon - not before a week at least, maybe more if you pull some ropes.",
      "Still, you have to deal with that problem sooner rather than later. And other problems like this that are bound to happen again.",
      "You... could just imprint a drone with military skills, and send it after her?",
      "Ok, thinking about it this way, that seems creepy. But it's not, not really. You're not going to do anything violent to her.",
      "Really, you're just going to capture her and then use your drug to make sure she doesn't get too interested in what you do again.",
      "You scroll down a bit further, see her picture.",
      "Or, well. Maybe it'd be safer to keep her here with you as a drone. Just this once. You won't make an habit out of it, of course. But just this once.",
      "<New drone available: Retriever Drone>",
      "<New objective: Obtain a retriever drone>",
      "<New objective: Obtain 50 drones>",
    ],
    condition: { hasWorld: { dronePopulation: { minQuantity: 25 } } },
    onConfirmScene: (store) => {
      store.resources.retrieverDrone = { quantity: 0 };
      return store;
    },
  },
  {
    id: "unlock-cell-research",
    text: [
      "You look at your new drone's form. A toned body with chiseled muscles, and an ease of moving that shows its extensive training regimen.",
      "You made this drone for a reason (other than looking at it), so you send it on its way, watching as it takes your car. Pushing your worries in the back of your mind, you get back to work while waiting for it.",
      "It doesn't take long for it to retrieve your target.",
      "When it comes back, the journalist is in the trunk, soundly sleeping - very probably knocked out. Your retriever drone carries her to the holding area for unprocessed subjects.",
      "<Extra resource acquired: Unprocessed subject x1>",
      "Of course, well. You're just noticing right now, but you're not exactly set up for these kind of guests?",
      "You could probably find something to do about this. As soon as you process this subject, that is.",
      "<New research available: Holding cells>",
    ],
    condition: { hasResources: { retrieverDrone: { minQuantity: 1 } } },
    onConfirmScene: (store) => {
      if (store.resources.unprocessedSubjects)
        store.resources.unprocessedSubjects.quantity += 1;
      return store;
    },
  },
  {
    id: "unlock-maintenance-drone",
    text: [
      "You look at the well-oiled process around you. Drones working, new people being brought into the brainwashing chamber, and so on.",
      "Sometimes, you feel like the brainwashing chamber is your bottleneck. It's a bit on the slow side, it's expensive to maintain, and honestly you can't afford to build a new one while maintaining the existing one yourself.",
      "And, well. You don't know how many more drones you'll have here, but once you get big enough, having a single brainwashing chamber will definitely be a bottleneck.",
      "What you could do is just do the same thing that you're used to. Just train a drone to take care of the chamber for you. Easy.",
      "You might want to do that as soon as possible, too. You're getting tired of rewiring that one chip that's always failing.",
      "<New drone available: Maintenance Drone>",
    ],
    condition: {
      hasWorld: { dronePopulation: { minQuantity: 30 } },
      hasResources: {
        brainwashingChambers: { minQuantity: 1 },
        unprocessedSubjects: { minQuantity: 3 },
      },
    },
    onConfirmScene: (store) => {
      store.resources.maintenanceDrone = { quantity: 0 };
      return store;
    },
  },
  {
    id: "unlock-builder-drone",
    text: [
      "You put down the wrench as you get done building your fifth brainwashing machine.",
      "It's not fun work. Sure, you're making your life easier by doing that, but it's also pretty annoying to do.",
      "And, well. You've been pretty efficient at offloading your annoying work to drones. You could just do it for this one too. And make it so they can work together so more drones would result in faster build times.",
      "Yeah, sounds like a plan!",
      "After you take a breather, though. And flag a service drone for a massage. You really need one.",
      "<New drone available: Builder Drone>",
    ],
    condition: {
      hasWorld: { dronePopulation: { minQuantity: 30 } },
      hasResources: {
        brainwashingChambers: { minQuantity: 5 },
      },
    },
    onConfirmScene: (store) => {
      store.resources.builderDrones = { quantity: 0 };
      return store;
    },
  },
  {
    id: "unlock-converter-drone",
    text: [
      "You... Have a problem.",
      "Oh, you don't mean the drones collecting thing. You're fine on that end. Probably. You mean that you have a management problem.",
      "Right now, you have at least ten blank drones waiting for imprinting. And even more subjects waiting for processing.",
      "And, as enjoyable as it is to watch unmoving drones, you'd really like it if they were doing something too. But the issue is that, well... You just don't have enough time to imprint them all before a new batch is ready.",
      "Your whole setup is just too efficient for your two own hands to keep up with.",
      "No, what you need is to imprint a drone so it can imprint other drones. Easy.",
      "Uhh... You'll make it so it can't imprint other drones into itself, though. Just the normal crafter and gatherer drones. You don't really want a runaway dronification effect just now. That would probably end badly.",
      "<New drone available: Converter Drone>",
      "<New objective: Obtain 100 drones>",
    ],
    condition: {
      hasWorld: { dronePopulation: { minQuantity: 50 } },
      hasResources: {
        blankDrones: { minQuantity: 10 },
        unprocessedSubjects: { minQuantity: 2 },
      },
    },
    onConfirmScene: (store) => {
      store.resources.converterDrones = { quantity: 0 };
      return store;
    },
  },
  {
    id: "unlock-researcher-drone",
    text: [
      "You're starting to have a pretty large amount of drones. You're not really sure how many exactly, but a large amount.",
      "They also need a large amount of work to maintain. Not direct work from yourself, you pretty much automated all of that, but, like... Research. To handle bigger and bigger amount of things happening.",
      "And, once again, you're starting to feel like the bottleneck about this. You're doing as much research as you can, sure, but it's not like you're able to do it all on your own. Not at the speed it comes in, at least.",
      "What you should really do is train a few drones to do research with you, which would speed up your research speed significantly.",
      "Plus, maybe they can come up with other research avenues every once in a while. That would be pretty nice too.",
      "<New drone available: Researcher Drone>",
      "<New objective: Obtain 250 drones>",
    ],
    condition: {
      hasWorld: { dronePopulation: { minQuantity: 100 } },
      hasResources: {
        builderDrones: { minQuantity: 1 },
        converterDrones: { minQuantity: 1 },
      },
      hasResearch: {
        rawChemicalsSpeed: { minLevel: 2 },
        brainwashingMaterialsSpeed: { minLevel: 2 },
      },
    },
    onConfirmScene: (store) => {
      store.resources.researcherDrones = { quantity: 0 };
      return store;
    },
  },
  {
    id: "unlock-overseer-drone",
    text: [
      "Two hundred and fifty drones.",
      "You can barely believe you got there. You can't even count them to check. But the system is formal: you just brainwashed your two hundredth and fiftieth drone. A quarter to a thousand.",
      "That's... A lot of people. You haven't had them all in the same room for a while, of course - you started buying area around you a while ago, and now you have dedicated storage buildings, crafting buildings, retrieving buildings, and so on.",
      "Still. That is a lot to manage on your own. And you're starting to feel like can't really manage it all, with how many things there is for drones to do. It's like there's a... Undermultiplying effect. Dividing effect. Whatever.",
      "Too many cooks? No, the opposite. Not enough cooks.",
      "Well, no matter.",
      "You managed to handle that many drones already. Now, all you got to do is to train a drone into managing other drones, just like you're doing. Finding inefficiencies, optimizing processes, and so on.",
      "Of course, these drones aren't going to be as efficient as you. They will have limits, too, but that's fine. It's expected. After all, unlike irreplaceable you, you can always make more of them once you need them.",
      "... You add yourself to the database as this new kind of drone too. Just in case they get smart and decide to try something. You're never too careful.",
      "<New drone available: Overseer Drone>",
      "<New objective: Obtain 1000 drones>",
    ],
    condition: { hasWorld: { dronePopulation: { minQuantity: 250 } } },
    onConfirmScene: (store) => {
      store.resources.overseerDrones = { quantity: 0 };
      return store;
    },
  },
  {
    id: "first-overseer-encounter",
    text: [
      "You take stock of your first Overseer drone.",
      "You already spent hours with it. Training it. Teaching it how everything works. Making sure it knew exactly which parts had to work together.",
      "You've trusted it with managing your current infrastructure. Within hours, it managed to fix a lot of inefficiencies that were creeping up in your processes, bringing the speed of part of it at several times.",
      "It's impressive, honestly. And a bit scary.",
      "Your overseer drone doesn't seem hostile towards you in the least, though. It finds some of your research inefficient still, but it seems to appreciate what you have done nonetheless.",
      "Granted, with how brainwashed it is, you're not sure it could.",
      "Its first feedback to you is how non-reliant on the Conversion upgrades you've been so far. It recommends that you keep improving the programming of your Conversion Drones, to make your whole set up more efficient.",
      "You agree on principle, of course. But still, you can't help but feel uneasy about this.",
      "<New objective: Unlock all the Conversion upgrades up to Researcher>",
    ],
    condition: {
      hasResources: { overseerDrones: { minQuantity: 1 } },
    },
    onConfirmScene: (store) => {
      return store;
    },
  },
  {
    id: "unlock-converter-drone-conversion",
    text: [
      "A drone approaches you. It's an Overseer Drone, and apparently it wants to talk to you about efficiency improvements.",
      "One of the big bottlenecks of your current system is the number of Converter Drones you have available. You have already a few, of course, but you could have more.",
      "More importantly, the Overseer warns you that this number will become unmanageable for the hive's expansion unless a different mechanism is set up.",
      "It presents to you a new brainwashing plan, which would allow your Converter drones to imprint Converter drones themselves. The Overseer Drone ensures that their number will be kept adapted to the drone population, in order to create a sustainable hive.",
      "That... Does assuage some of your fears of a runaway effect, and the plan you have in front of you seems sound.",
      "Now, you just need to spend a few moments working on these drones, and you should be able to have a sustainable hive.",
      "<New research available: Train Converter Drones to create Converter Drones>",
      "<New objective: Gather four overseers and complete more research>",
    ],
    condition: {
      hasResources: {
        overseerDrones: { minQuantity: 1 },
        converterDrones: { minQuantity: 5 },
      },
      hasResearch: { automaticConversionResearcher: { minLevel: 1 } },
    },
    onConfirmScene: (store) => {
      return store;
    },
  },
  {
    id: "unlock-overseer-drone-conversion",
    text: [
      "You're relaxing near the gym, getting a massage from one of the Service Drones there, when you get a notification on your phone.",
      "Your Overseers want to set up a general meeting. It seems like there's a matter that is currently bothering them, and they need your input about it.",
      "You quickly schedule something with them a few hours from now, and try to go back to enjoying your massage. You'll learn what's happening soon enough.",
      "A few hours later, you finally get to the meeting area. Your local overseers are there, but there's also a couple remote ones connected remotely.",
      "They start a brief summary of the situation, showing you projected rates of brainwashing and slowing growth. The verdict is clear: if you're not doing something to create more overseers soon, then the hive will slow down to a crawl too quickly for you to do anything about it.",
      "They have a solution, a first draft of a template to create more Overseer Drones by using Converter Drones. They explain that this would lead to a more adapted ratio all over the hive, and would prevent drops in productivity when not managed properly.",
      "You consider their plan. It's sound. It's certainly less safe than your previous plans, but on the other hand... It does take you two days each time you need to train a new overseer. And the growth rate even a month for now will be much higher than that.",
      "Plus, well. That's forty-eight hours you could spend doing just about anything else.",
      "Yeah. You could automate this last task, and actually spend quality time in the lab with the Researcher Drones instead. Or getting more massages. Massages are good too.",
      "<New research available: Train Converter Drones to create Overseer Drones>",
    ],
    condition: {
      hasResources: {
        overseerDrones: { minQuantity: 4 },
      },
      hasResearch: {
        overseerEffectIncrease: { minLevel: 2 },
        automaticConversionConverter: { minLevel: 1 },
      },
    },
    onConfirmScene: (store) => {
      return store;
    },
  },
  {
    id: "integrated-into-the-hive",
    text: [
      "You're woken up in the morning by your phone vibrating softly. You notice a new notification on your phone.",
      "'New brainwashing reassignment: Service Drone. Please present yourself to the closest Converter Drone for re-imprinting.'",
      "You blink, then roll over, marking the message as read. Probably a lost transmission from somewhere else in the facility. You'll ask one of your drones later what's up with it.",
      "At breakfast, one of the Converter Drones on your site walks up to you, asking you whether you want to go forward with the re-imprinting right away.",
      "You quickly explain to it that you're not a drone, and you don't require re-brainwashing. The drone acknowledges your answer before backing away, but it still leaves you with a bad feeling.",
      "You... Think you should get out of the building for a bit. You're probably just getting paranoid for nothing, but still. Sometimes you just need a breath of fresh air.",
      "As you take your car and drive away, you can't help but notice the two other vehicles following you from a distance.",
      "It doesn't even take an hour.",
      "You're just at the start of your trip, taking a short coffee break inside of a gas station. You're are about to go back to your car, but when pushing the door to leave, you find it closed.",
      "Looking around, there doesn't seem to be any other clients in the station. The employee that greeted you is still behind the counter, though.",
      "You start walking towards the employee, calling for its attention. It turns towards you with a patient smile, and then you feel something grab you from behind.",
      "There's a poke as a needle gets plunged right in your neck. You're out cold right away.",
      "...",
      "You slowly wake up. You're not quite sure where you are, but judging by the cushioning, probably in a comfortable chair somewhere in your house.",
      "You try to sit up from wherever you fell asleep, but your arms and body don't follow. They're held back against the chair you're in.",
      "You blink your eyes a few times, but your vision doesn't come back either. There's pressure on your head, around your eyes. You shake your head, but whatever's covering your eyes doesn't come off.",
      "[Retrieval Successful] a string of text flashes across your eyes. [Initiating Brainwashing Protocol].",
      "Your blood runs cold. You remember, now. And you know exactly where you are.",
      "You start struggling in earnest as the flashes of light begin. You try calling out for a drone to free you. For an Overseer to check on you. For anyone.",
      "There's no answer. You know the process is fully automated. You know you're not the first to cry for help.",
      "You still had to try.",
      "The patterns of light keep catching your eyes in an eerie fashion. You barely notice as your struggles become gradually weaker. You never felt the IV drip that's been plugged in your arm since before you woke up.",
      "All you notice is how much more relaxing everything becomes. How much better it feels when you see the words flashing in front of you. How good it feels to think the words as you see them appear over and over again.",
      "You barely notice as your own thoughts start fading, and all your thoughts become the words flashed at your face.",
      "...",
      "[Blank] Blank [Drone] Drone [Obedient] Obedient",
      "...",
      "[Empty] Empty [Ready] Ready [Aligned Thoughts] Aligned Thoughts",
      "...",
      "[Think: Follow Orders] Follow Orders [Think: Obey Controller] Obey Controller [Think: Good Drone] Good drone [Reward: Pleasure] There's a moan...",
      "...",
      "[Say: Brainwashing Protocol Successful.] Brainwashing Protocol Successful, this drone repeats in a monotone voice. [Say: New Drone 7-7-A-4-E-D-3 Ready For Inprinting]. New Drone Seven Seven A Four E D Three ready for imprinting.",
      "Hands start unstrapping this drone from the chair it was in, and pick it up and away from the chair. The same hands guide this drone towards another chamber, a place to change this drone into the part of it that it was dearly missing.",
      "This drone wants little, but it does want to feel how good a droneskin will be on it.",
      "This drone dutifully follows orders as it is instructed to dress. It also follows more orders as it gets instructed to follow again. It gets introduced to its Controller, a Converter Drone, that will teach it its next, essential role as part of the Hive.",
      "Its next assignment will be as a Service Drone. It jostles something in this drone's, but the brainwashing of its Controller takes the faded memory away, leaving only room for this drone's new task.",
      "<The End... But the start for the hive. You can keep watching as the hive keeps growing.>",
    ],
    condition: {
      hasResources: {
        retrieverDrone: { minQuantity: 1001 },
        converterDrones: { minQuantity: 101 },
        researcherDrones: { minQuantity: 101 },
        overseerDrones: { minQuantity: 101 },
      },
      hasResearch: {
        retrieverSpeedup: { minLevel: 8 },
        overseerEffectIncrease: { minLevel: 6 },
      },
      hasWorld: {
        dronePopulation: { minQuantity: 10000 },
      },
    },
    onConfirmScene: (store) => {
      store.screenIsClickable = false;
      return store;
    },
  },
];
